pub struct ProviderOptions {
pub providers: Vec<ProviderInfo>,
}Expand description
Options for specifying content providers
Fields
providers: Vec<ProviderInfo>An optional list of peers known to host at least the root block of the DAG that will be fetched.
If this list is omitted, or if the peers cannot supply the root or any
child blocks, a findProviders routing query will be run to find peers
that can supply the blocks.